message

package
v0.0.0-...-8f8ba8d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 9, 2023 License: GPL-3.0 Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func TryMainPkg

func TryMainPkg(w http.ResponseWriter, r *http.Request)

Types

type Message

type Message struct {
	Text string
	Time int64
}

Message represents a message with a text and a timestamp

func NewMessage

func NewMessage(text string) *Message

NewMessage creates a new message with a given text

Jump to